@@ -146,6 +146,8 @@ OC.L10N.register(
     "Undo" : "Vrátit zpět",
     "Deleted cards" : "Smazané karty",
     "Share board with a user, group or circle …" : "Sdílet tabuli s uživatelem, skupinou nebo okruhem…",
+    "Searching for users, groups and circles …" : "Hledání v uživatelích, skupinách a okruzích…",
+    "No participants found" : "Nenalezeni žádní účastníci",
     "Board owner" : "Vlastník tabule",
     "(Group)" : "(Skupina)",
     "(Circle)" : "(Okruh)",
@@ -153,6 +155,7 @@ OC.L10N.register(
     "Can share" : "Může sdílet",
     "Can manage" : "Může spravovat",
     "Delete" : "Smazat",
+    "Failed to create share with {displayName}" : "Nepodařilo se vytvořit sdílení s {displayName}",
     "Add a new list" : "Přidat nový sloupec",
     "Archive all cards" : "Archivovat všechny karty",
     "Delete list" : "Smazat seznam",
@@ -160,6 +163,7 @@ OC.L10N.register(
     "Archive all cards in this list" : "Archivovat všechny karty v tomto seznamu",
     "Add a new card" : "Přidat novou kartu",
     "Card name" : "Název karty",
+    "List deleted" : "Seznam smazán",
     "Edit" : "Upravit",
     "Add a new tag" : "Přidat nový štítek",
     "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
@@ -171,6 +175,12 @@ OC.L10N.register(
     "Restore Attachment" : "Obnovit přílohu",
     "Open in sidebar view" : "Otevřít v zobrazení v postranním panelu",
     "Open in bigger view" : "Otevřít ve větším zobrazení",
+    "Attachments" : "Přílohy",
+    "Comments" : "Komentáře",
+    "Modified" : "Změněno",
+    "Created" : "Vytvořeno",
+    "The title cannot be empty." : "Nadpis je třeba vyplnit.",
+    "No comments yet. Begin the discussion!" : "Zatím bez komentářů. Zahajte diskuzi!",
     "Assign a tag to this card…" : "Přiřadit této kartě štítek…",
     "Assign to users" : "Přiřadit k uživatelům",
     "Assign to users/groups/circles" : "Přiřadit uživatelům/skupinám/okruhům",
@@ -178,6 +188,13 @@ OC.L10N.register(
     "Due date" : "Termín",
     "Set a due date" : "Vybrat termín",
     "Remove due date" : "Odstranit termín",
+    "Select Date" : "Vybrat datum",
+    "Save" : "Uložit",
+    "The comment cannot be empty." : "Komentář je třeba vyplnit",
+    "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
+    "In reply to" : "V odpověď na",
+    "Reply" : "Odpovědět",
+    "Update" : "Aktualizovat",
     "Description" : "Popis",
     "(Unsaved)" : "(Neuloženo)",
     "(Saving…)" : "(Ukládání…)",
@@ -185,30 +202,18 @@ OC.L10N.register(
     "Edit description" : "Upravit popis",
     "View description" : "Zobrazit popis",
     "Add Attachment" : "Přidat přílohu",
-    "Attachments" : "Přílohy",
-    "Comments" : "Komentáře",
     "Choose attachment" : "Zvolte přílohu",
-    "Select Date" : "Vybrat datum",
-    "Modified" : "Změněno",
-    "Created" : "Vytvořeno",
-    "The title cannot be empty." : "Nadpis je třeba vyplnit.",
-    "No comments yet. Begin the discussion!" : "Zatím bez komentářů. Zahajte diskuzi!",
-    "Save" : "Uložit",
-    "The comment cannot be empty." : "Komentář je třeba vyplnit",
-    "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
-    "In reply to" : "V odpověď na",
-    "Reply" : "Odpovědět",
-    "Update" : "Aktualizovat",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
     "Assign to me" : "Přiřadit mě",
     "Unassign myself" : "Zrušit přiřazení sobě",
+    "Move card" : "Přesunout kartu",
     "Unarchive card" : "Zrušit archivaci karty",
     "Archive card" : "Archivovat kartu",
     "Delete card" : "Smazat kartu",
-    "Move card" : "Přesunout kartu",
     "Move card to another board" : "Přesunout kartu na jinou tabuli",
     "Select a list" : "Vyberte sloupec",
+    "Card deleted" : "Karta smazána",
     "seconds ago" : "před několika sekundami",
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
@@ -218,12 +223,8 @@ OC.L10N.register(
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
     "Board name" : "Název tabule",
-    "Edit board" : "Upravit tabuli",
-    "Clone board " : "Klonovat tabuli ",
-    "Unarchive board " : "Vrátit tabuli zpět z archivu ",
-    "Archive board " : "Archivovat tabuli ",
-    "Delete board " : "Smazat tabuli",
     "Board details" : "Podrobnosti o desce",
+    "Edit board" : "Upravit tabuli",
     "Board {0} deleted" : "Tabule {0} smazána",
     "An error occurred" : "Došlo k chybě",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
