@@ -163,6 +163,11 @@ OC.L10N.register(
     "Add this attachment" : "この添付ファイルを追加",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
+    "Attachments" : "添付ファイル",
+    "Comments" : "コメント",
+    "Modified" : "更新日時",
+    "Created" : "作成時刻",
+    "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
     "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
     "Assign to users" : "ユーザーに割り当てる",
     "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
@@ -170,6 +175,13 @@ OC.L10N.register(
     "Due date" : "期限",
     "Set a due date" : "期限を設定",
     "Remove due date" : "期限を削除",
+    "Select Date" : "日付を選択",
+    "Save" : "保存",
+    "The comment cannot be empty." : "コメントを空にすることはできません。",
+    "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
+    "In reply to" : "返信",
+    "Reply" : "返信",
+    "Update" : "更新",
     "Description" : "説明",
     "(Unsaved)" : "(未保存)",
     "(Saving…)" : "(保存中…)",
@@ -177,27 +189,15 @@ OC.L10N.register(
     "Edit description" : "説明を編集",
     "View description" : "説明を表示",
     "Add Attachment" : "添付ファイルを追加",
-    "Attachments" : "添付ファイル",
-    "Comments" : "コメント",
     "Choose attachment" : "添付ファイルを選択",
-    "Select Date" : "日付を選択",
-    "Modified" : "更新日時",
-    "Created" : "作成時刻",
-    "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
-    "Save" : "保存",
-    "The comment cannot be empty." : "コメントを空にすることはできません。",
-    "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
-    "In reply to" : "返信",
-    "Reply" : "返信",
-    "Update" : "更新",
     "(group)" : "(グループ)",
     "(circle)" : "(サークル)",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
+    "Move card" : "カードの移動",
     "Unarchive card" : "カードのアーカイブを解除する",
     "Archive card" : "カードをアーカイブ",
     "Delete card" : "カードを削除する",
-    "Move card" : "カードの移動",
     "Move card to another board" : "カードを他のボードに移動",
     "Select a list" : "リストを選択",
     "seconds ago" : "数秒前",
@@ -206,12 +206,8 @@ OC.L10N.register(
     "Shared with you" : "あなたと共有済み",
     "Limit deck usage of groups" : "デッキの使用をグループに制限",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
-    "Edit board" : "ボードを編集",
-    "Clone board " : "ボードを複製",
-    "Unarchive board " : "ボードのアーカイブを解除",
-    "Archive board " : "ボードをアーカイブ",
-    "Delete board " : "ボードを削除",
     "Board details" : "ボードの詳細",
+    "Edit board" : "ボードを編集",
     "Board {0} deleted" : "ボード {0} 削除済み",
     "An error occurred" : "エラーが発生しました",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
