@@ -167,6 +167,11 @@ OC.L10N.register(
     "Add this attachment" : "Pridať túto prílohu",
     "Delete Attachment" : "Odstrániť prílohu",
     "Restore Attachment" : "Obnoviť prílohu",
+    "Attachments" : "Prílohy",
+    "Comments" : "Komentáre",
+    "Modified" : "Upravené",
+    "Created" : "Vytvorené",
+    "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
     "Assign a tag to this card…" : "Tejto karte priradiť štítok…",
     "Assign to users" : "Priradiť používateľom",
     "Assign to users/groups/circles" : "Priradiť používateľom/skupinám/okruhom",
@@ -174,6 +179,13 @@ OC.L10N.register(
     "Due date" : "Termín dokončenia",
     "Set a due date" : "Nastaviť termín",
     "Remove due date" : "Odstrániť termín dokončenia",
+    "Select Date" : "Vybrať dátum",
+    "Save" : "Uložiť",
+    "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
+    "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
+    "In reply to" : "Odpoveď na",
+    "Reply" : "Odpoveď",
+    "Update" : "Aktualizovať",
     "Description" : "Popis",
     "(Unsaved)" : "(Neuložené)",
     "(Saving…)" : "(Ukladanie…)",
@@ -181,27 +193,15 @@ OC.L10N.register(
     "Edit description" : "Upraviť popis",
     "View description" : "Zobraziť popis",
     "Add Attachment" : "Pridať prílohu",
-    "Attachments" : "Prílohy",
-    "Comments" : "Komentáre",
     "Choose attachment" : "Vybrať prílohu",
-    "Select Date" : "Vybrať dátum",
-    "Modified" : "Upravené",
-    "Created" : "Vytvorené",
-    "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
-    "Save" : "Uložiť",
-    "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
-    "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
-    "In reply to" : "Odpoveď na",
-    "Reply" : "Odpoveď",
-    "Update" : "Aktualizovať",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
     "Assign to me" : "Priradiť mne",
     "Unassign myself" : "Zrušiť priradenie mne",
+    "Move card" : "Presunúť kartu",
     "Unarchive card" : "Zrušiť archiváciu karty",
     "Archive card" : "Archivovať kartu",
     "Delete card" : "Zmazať kartu",
-    "Move card" : "Presunúť kartu",
     "Move card to another board" : "Presunúť kartu na inú nástenku",
     "Select a list" : "Vybrať zoznam",
     "seconds ago" : "pred niekoľkými sekundami",
@@ -210,12 +210,8 @@ OC.L10N.register(
     "Shared with you" : "Vám sprístupnené",
     "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
-    "Edit board" : "Upraviť nástenku",
-    "Clone board " : "Zdvojiť nástenku",
-    "Unarchive board " : "Zrušiť archiváciu nástenky",
-    "Archive board " : "Archivovať nástenku",
-    "Delete board " : "Zmazať nástenku",
     "Board details" : "Podrobnosti o nástenke",
+    "Edit board" : "Upraviť nástenku",
     "Board {0} deleted" : "Nástenka {0} vymazaná",
     "An error occurred" : "Vyskytla sa chyba",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
