@@ -146,6 +146,7 @@ OC.L10N.register(
     "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
     "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
+    "Searching for users, groups and circles …" : "Iskanje uporabnikov, skupin in krogov ...",
     "No participants found" : "Ni zaznanih udeleženev",
     "Board owner" : "Lastnik zbirke",
     "(Group)" : "(Skupina)",
@@ -201,6 +202,7 @@ OC.L10N.register(
     "Edit description" : "Uredi opis",
     "View description" : "Pokaži opis",
     "Add Attachment" : "Dodaj prilogo",
+    "Write a description …" : "Vpišite opis ...",
     "Choose attachment" : "Izbor priloge",
     "(group)" : "(skupina)",
     "(circle)" : "(krog)",
@@ -224,7 +226,16 @@ OC.L10N.register(
     "Board name" : "Ime  zbirke",
     "Board details" : "Podrobnosti zbirke",
     "Edit board" : "Uredi zbirko",
+    "Clone board" : "Kloniraj zbirko",
+    "Unarchive board" : "Povrni zbirko",
+    "Archive board" : "Arhiviraj zbirko",
+    "All cards" : "Vse naloge",
+    "Assigned cards" : "Dodeljene naloge",
+    "No notifications" : "Ni obvestil",
+    "Delete board" : "Izbriši zbirko",
     "Board {0} deleted" : "Zbirka {0} je izbrisana",
+    "Only assigned cards" : "Le dodeljene naloge",
+    "No reminder" : "Ni vpisanih opomnikov",
     "An error occurred" : "Prišlo je do napake.",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
     "Delete the board?" : "Ali želite izbrisati zbirko?",
