@@ -202,6 +202,7 @@ OC.L10N.register(
     "Edit description" : "Ändra beskrivning",
     "View description" : "Visa beskrivning",
     "Add Attachment" : "Lägg till bilaga",
+    "Write a description …" : "Ange en beskrivning ...",
     "Choose attachment" : "Välj bilaga",
     "(group)" : " (grupp)",
     "(circle)" : "(cirkel)",
@@ -225,7 +226,19 @@ OC.L10N.register(
     "Board name" : "Tavlans namn",
     "Board details" : "Taveldetaljer",
     "Edit board" : "Ändra tavla",
+    "Clone board" : "Kopiera tavla",
+    "Unarchive board" : "Ta bort tavlan ur arkivet",
+    "Archive board" : "Arkivera tavla",
+    "Turn on due date reminders" : "Aktivera påminnelser om förfallodatum",
+    "Turn off due date reminders" : "Inaktivera påminnelser om förfallodatum",
+    "Due date reminders" : "Påminnelser om förfallodatum",
+    "All cards" : "Alla kort",
+    "Assigned cards" : "Tilldelade kort",
+    "No notifications" : "Inga aviseringar",
+    "Delete board" : "Radera tavla",
     "Board {0} deleted" : "Tavla {0} raderad",
+    "Only assigned cards" : "Bara tilldelade kort",
+    "No reminder" : "Ingen påminnelse",
     "An error occurred" : "Ett fel uppstod",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
     "Delete the board?" : "Ta bort tavlan?",
