@@ -98,6 +98,10 @@ OC.L10N.register(
     "Add this attachment" : "Долучити вкладення",
     "Delete Attachment" : "Забрати вкладення",
     "Restore Attachment" : "Відновити вкладення",
+    "Attachments" : "Вкладення",
+    "Comments" : "Коментарі",
+    "Modified" : "Змінено",
+    "Created" : "Створено",
     "Assign a tag to this card…" : "Додати позначку до цієї картки",
     "Assign to users" : "Призначити користувачам",
     "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
@@ -105,6 +109,11 @@ OC.L10N.register(
     "Due date" : "Протягом",
     "Set a due date" : "Встановити дату завершення",
     "Remove due date" : "Вилучити до",
+    "Select Date" : "Вкажіть дату",
+    "Save" : "Зберегти",
+    "In reply to" : "У відповідь",
+    "Reply" : "Відповісти",
+    "Update" : "Оновлення",
     "Description" : "Опис",
     "(Unsaved)" : "(Не збережено)",
     "(Saving…)" : "(Зберігання...)",
@@ -112,23 +121,14 @@ OC.L10N.register(
     "Edit description" : "Редагувати опис",
     "View description" : "Переглянути опис",
     "Add Attachment" : "Долучити вкладення",
-    "Attachments" : "Вкладення",
-    "Comments" : "Коментарі",
     "Choose attachment" : "Вибрати вкладення",
-    "Select Date" : "Вкажіть дату",
-    "Modified" : "Змінено",
-    "Created" : "Створено",
-    "Save" : "Зберегти",
-    "In reply to" : "У відповідь",
-    "Reply" : "Відповісти",
-    "Update" : "Оновлення",
     "(group)" : "(група)",
     "(circle)" : "(коло)",
     "Assign to me" : "Призначити мені",
+    "Move card" : "Пересунути картку",
     "Unarchive card" : "Розархівувати картку",
     "Archive card" : "Архівувати картку",
     "Delete card" : "Вилучити картку",
-    "Move card" : "Пересунути картку",
     "Move card to another board" : "Перемістити картку до іншої дошки",
     "Select a list" : "Виберіть список",
     "seconds ago" : "секунд тому",
@@ -136,12 +136,8 @@ OC.L10N.register(
     "Archived boards" : "Архівні дошки",
     "Shared with you" : "Вам надано доступ",
     "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
-    "Edit board" : "Редагувати дошку",
-    "Clone board " : "Копія дошки",
-    "Unarchive board " : "Розархівувати дошку",
-    "Archive board " : "Архівувати дошку",
-    "Delete board " : "Вилучити дошкуу",
     "Board details" : "Деталі дошки",
+    "Edit board" : "Редагувати дошку",
     "Board {0} deleted" : "Дошку {0} вилучено",
     "An error occurred" : "Виникла помилка",
     "Delete the board?" : "Вилучити дошку?",
