@@ -25,7 +25,6 @@ namespace OCA\Deck\Db;
 
 use Exception;
 use OCP\AppFramework\Db\Entity;
-
 use OCP\AppFramework\Db\QBMapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
@@ -82,7 +81,8 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		}
 
 		// make sure we only reset the notification flag if the duedate changes
-		if (in_array('duedate', $entity->getUpdatedFields(), true)) {
+		$updatedFields = $entity->getUpdatedFields();
+		if (isset($updatedFields['duedate']) && $updatedFields['duedate']) {
 			try {
 				/** @var Card $existing */
 				$existing = $this->find($entity->getId());
@@ -243,6 +243,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		$qb->select('id','title','duedate','notified')
 			->from('deck_cards')
 			->where($qb->expr()->lt('duedate', $qb->createFunction('NOW()')))
+			->andWhere($qb->expr()->eq('notified', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
 			->andWhere($qb->expr()->eq('archived', $qb->createNamedParameter(false, IQueryBuilder::PARAM_BOOL)))
 			->andWhere($qb->expr()->eq('deleted_at', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)));
 		return $this->findEntities($qb);
@@ -307,7 +308,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		$qb->execute();
 	}
 
-	public function isOwner($userId, $cardId) {
+	public function isOwner($userId, $cardId): bool {
 		$sql = 'SELECT owner FROM `*PREFIX*deck_boards` WHERE `id` IN (SELECT board_id FROM `*PREFIX*deck_stacks` WHERE id IN (SELECT stack_id FROM `*PREFIX*deck_cards` WHERE id = ?))';
 		$stmt = $this->db->prepare($sql);
 		$stmt->bindParam(1, $cardId, \PDO::PARAM_INT);
@@ -316,13 +317,12 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		return ($row['owner'] === $userId);
 	}
 
-	public function findBoardId($cardId) {
+	public function findBoardId($cardId): ?int {
 		$sql = 'SELECT id FROM `*PREFIX*deck_boards` WHERE `id` IN (SELECT board_id FROM `*PREFIX*deck_stacks` WHERE id IN (SELECT stack_id FROM `*PREFIX*deck_cards` WHERE id = ?))';
 		$stmt = $this->db->prepare($sql);
 		$stmt->bindParam(1, $cardId, \PDO::PARAM_INT);
 		$stmt->execute();
-		$row = $stmt->fetch();
-		return $row['id'];
+		return $stmt->fetchColumn() ?? null;
 	}
 
 	public function mapOwner(Card &$card) {
