@@ -26,9 +26,10 @@ namespace OCA\Deck\Service;
 
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
+use OCA\Deck\AppInfo\Application;
 use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\AclMapper;
-use OCA\Deck\Db\AssignedUsersMapper;
+use OCA\Deck\Db\AssignmentMapper;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\IPermissionMapper;
 use OCA\Deck\Db\Label;
@@ -37,6 +38,7 @@ use OCA\Deck\Db\StackMapper;
 use OCA\Deck\NoPermissionException;
 use OCA\Deck\Notification\NotificationHelper;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\IConfig;
 use OCP\IGroupManager;
 use OCP\IL10N;
 use OCA\Deck\Db\Board;
@@ -52,6 +54,8 @@ class BoardService {
 	private $stackMapper;
 	private $labelMapper;
 	private $aclMapper;
+	/** @var IConfig */
+	private $config;
 	private $l10n;
 	private $permissionService;
 	private $notificationHelper;
@@ -66,15 +70,17 @@ class BoardService {
 
 	private $boardsCache = null;
 
+
 	public function __construct(
 		BoardMapper $boardMapper,
 		StackMapper $stackMapper,
+		IConfig $config,
 		IL10N $l10n,
 		LabelMapper $labelMapper,
 		AclMapper $aclMapper,
 		PermissionService $permissionService,
 		NotificationHelper $notificationHelper,
-		AssignedUsersMapper $assignedUsersMapper,
+		AssignmentMapper $assignedUsersMapper,
 		IUserManager $userManager,
 		IGroupManager $groupManager,
 		ActivityManager $activityManager,
@@ -85,6 +91,7 @@ class BoardService {
 		$this->boardMapper = $boardMapper;
 		$this->stackMapper = $stackMapper;
 		$this->labelMapper = $labelMapper;
+		$this->config = $config;
 		$this->aclMapper = $aclMapper;
 		$this->l10n = $l10n;
 		$this->permissionService = $permissionService;
@@ -112,15 +119,7 @@ class BoardService {
 		$userBoards = $this->boardMapper->findAllByUser($userInfo['user'], null, null, $since, $includeArchived);
 		$groupBoards = $this->boardMapper->findAllByGroups($userInfo['user'], $userInfo['groups'],null, null, $since, $includeArchived);
 		$circleBoards = $this->boardMapper->findAllByCircles($userInfo['user'], null, null,  $since, $includeArchived);
-		$mergedBoards = array_merge($userBoards, $groupBoards, $circleBoards);
-		$result = [];
-		/** @var Board $item */
-		foreach ($mergedBoards as &$item) {
-			if (!array_key_exists($item->getId(), $result)) {
-				$result[$item->getId()] = $item;
-			}
-		}
-		return array_values($result);
+		return array_unique(array_merge($userBoards, $groupBoards, $circleBoards));
 	}
 	/**
 	 * @return array
@@ -151,6 +150,7 @@ class BoardService {
 				'PERMISSION_MANAGE' => $permissions[Acl::PERMISSION_MANAGE] ?? false,
 				'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
 			]);
+			$this->enrichWithBoardSettings($item);
 			$result[$item->getId()] = $item;
 		}
 		$this->boardsCache = $result;
@@ -190,6 +190,7 @@ class BoardService {
 			'PERMISSION_SHARE' => $permissions[Acl::PERMISSION_SHARE] ?? false
 		]);
 		$this->enrichWithUsers($board);
+		$this->enrichWithBoardSettings($board);
 		$this->boardsCache[$board->getId()] = $board;
 		return $board;
 	}
@@ -476,6 +477,15 @@ class BoardService {
 		return [$edit, $share, $manage];
 	}
 
+	public function enrichWithBoardSettings(Board $board) {
+		$globalCalendarConfig = (bool)$this->config->getUserValue($this->userId, Application::APP_ID, 'calendar', true);
+		$settings = [
+			'notify-due' => $this->config->getUserValue($this->userId, Application::APP_ID, 'board:' . $board->getId() . ':notify-due', ConfigService::SETTING_BOARD_NOTIFICATION_DUE_ASSIGNED),
+			'calendar' => $this->config->getUserValue($this->userId, Application::APP_ID, 'board:' . $board->getId() . ':calendar', $globalCalendarConfig),
+		];
+		$board->setSettings($settings);
+	}
+
 	/**
 	 * @param $boardId
 	 * @param $type
@@ -532,7 +542,7 @@ class BoardService {
 		$this->changeHelper->boardChanged($boardId);
 
 		// TODO: use the dispatched event for this
-		$version = \OC_Util::getVersion()[0];
+		$version = \OCP\Util::getVersion()[0];
 		if ($version >= 16) {
 			try {
 				$resourceProvider = \OC::$server->query(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
@@ -613,7 +623,7 @@ class BoardService {
 		$acl = $this->aclMapper->find($id);
 		$this->boardMapper->mapAcl($acl);
 		if ($acl->getType() === Acl::PERMISSION_TYPE_USER) {
-			$assignements = $this->assignedUsersMapper->findByUserId($acl->getParticipant());
+			$assignements = $this->assignedUsersMapper->findByParticipant($acl->getParticipant());
 			foreach ($assignements as $assignement) {
 				$this->assignedUsersMapper->delete($assignement);
 			}
@@ -621,7 +631,7 @@ class BoardService {
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_BOARD, $acl, ActivityManager::SUBJECT_BOARD_UNSHARE);
 		$this->changeHelper->boardChanged($acl->getBoardId());
 
-		$version = \OC_Util::getVersion()[0];
+		$version = \OCP\Util::getVersion()[0];
 		if ($version >= 16) {
 			try {
 				$resourceProvider = \OC::$server->query(\OCA\Deck\Collaboration\Resources\ResourceProvider::class);
