@@ -28,7 +28,7 @@ namespace OCA\Deck\Service;
 
 use OCA\Deck\Activity\ActivityManager;
 use OCA\Deck\Activity\ChangeSet;
-use OCA\Deck\Db\AssignedUsersMapper;
+use OCA\Deck\Db\AssignmentMapper;
 use OCA\Deck\Db\Card;
 use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\Acl;
@@ -69,7 +69,7 @@ class CardService {
 		PermissionService $permissionService,
 		BoardService $boardService,
 		NotificationHelper $notificationHelper,
-		AssignedUsersMapper $assignedUsersMapper,
+		AssignmentMapper $assignedUsersMapper,
 		AttachmentService $attachmentService,
 		ActivityManager $activityManager,
 		ICommentsManager $commentsManager,
@@ -98,7 +98,7 @@ class CardService {
 	public function enrich($card) {
 		$cardId = $card->getId();
 		$this->cardMapper->mapOwner($card);
-		$card->setAssignedUsers($this->assignedUsersMapper->find($cardId));
+		$card->setAssignedUsers($this->assignedUsersMapper->findAll($cardId));
 		$card->setLabels($this->labelMapper->findAssignedLabelsForCard($cardId));
 		$card->setAttachmentCount($this->attachmentService->count($cardId));
 		$user = $this->userManager->get($this->currentUser);
@@ -136,7 +136,7 @@ class CardService {
 
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_READ);
 		$card = $this->cardMapper->find($cardId);
-		$assignedUsers = $this->assignedUsersMapper->find($card->getId());
+		$assignedUsers = $this->assignedUsersMapper->findAll($card->getId());
 		$attachments = $this->attachmentService->findAll($cardId, true);
 		$card->setAssignedUsers($assignedUsers);
 		$card->setAttachments($attachments);
@@ -172,6 +172,10 @@ class CardService {
 			throw new BadRequestException('title must be provided');
 		}
 
+		if (mb_strlen($title) > Card::TITLE_MAX_LENGTH) {
+			throw new BadRequestException('The title cannot exceed 255 characters');
+		}
+
 		if (is_numeric($stackId) === false) {
 			throw new BadRequestException('stack id must be a number');
 		}
@@ -270,6 +274,10 @@ class CardService {
 			throw new BadRequestException('title must be provided');
 		}
 
+		if (mb_strlen($title) > Card::TITLE_MAX_LENGTH) {
+			throw new BadRequestException('The title cannot exceed 255 characters');
+		}
+
 		if (is_numeric($stackId) === false) {
 			throw new BadRequestException('stack id must be a number $$$');
 		}
@@ -361,6 +369,10 @@ class CardService {
 			throw new BadRequestException('title must be provided');
 		}
 
+		if (mb_strlen($title) > Card::TITLE_MAX_LENGTH) {
+			throw new BadRequestException('The title cannot exceed 255 characters');
+		}
+
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
 			throw new StatusException('Operation not allowed. This board is archived.');
@@ -538,7 +550,7 @@ class CardService {
 		}
 		$label = $this->labelMapper->find($labelId);
 		$this->cardMapper->assignLabel($cardId, $labelId);
-		$this->changeHelper->cardChanged($cardId, false);
+		$this->changeHelper->cardChanged($cardId);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_LABEL_ASSIGN, ['label' => $label]);
 
 		$this->eventDispatcher->dispatch(
@@ -574,7 +586,7 @@ class CardService {
 		}
 		$label = $this->labelMapper->find($labelId);
 		$this->cardMapper->removeLabel($cardId, $labelId);
-		$this->changeHelper->cardChanged($cardId, false);
+		$this->changeHelper->cardChanged($cardId);
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_LABEL_UNASSING, ['label' => $label]);
 
 		$this->eventDispatcher->dispatch(
@@ -590,7 +602,7 @@ class CardService {
 	 */
 	public function findAllWithDue($userId) {
 		$cards = $this->cardMapper->findAllWithDue($userId);
-		
+
 		return $cards;
 	}
 
@@ -602,7 +614,7 @@ class CardService {
 	 */
 	public function findAssignedCards($userId) {
 		$cards = $this->cardMapper->findAssignedCards($userId);
-		
+
 		return $cards;
 	}
 }
